pub fn py_fx_local_from_utc(
session: ForexSession,
time_now: DateTime<Utc>,
) -> PyResult<String>Expand description
Converts a UTC timestamp to the local time for the given Forex session.
pub fn py_fx_local_from_utc(
session: ForexSession,
time_now: DateTime<Utc>,
) -> PyResult<String>Converts a UTC timestamp to the local time for the given Forex session.